export default class EventBus {
    constructor() {
        this.subscribers = new Map();
    }
    subscribe(type, handler) {
        if (!this.subscribers.has(type)) {
            this.subscribers.set(type, new Set());
        }
        const handlers = this.subscribers.get(type);
        handlers.add(handler);
        return () => {
            handlers.delete(handler);
        };
    }
    dispatch(type, ...args) {
        const handlers = this.subscribers.get(type);
        if (handlers) {
            // handler needed a type assertion to fix type bug
            handlers.forEach(handler => {
                handler(...args);
            });
        }
    }
}
//# sourceMappingURL=EventBus.js.map